jdk/src/share/classes/java/time/LocalDate.java
changeset 20519 eee7a92074fd
parent 20517 1336a85b3d52
child 20520 0952771e3e25
--- a/jdk/src/share/classes/java/time/LocalDate.java	Fri Aug 30 11:43:57 2013 +0100
+++ b/jdk/src/share/classes/java/time/LocalDate.java	Wed Sep 04 15:18:54 2013 +0100
@@ -1642,12 +1642,12 @@
      * </pre>
      * The choice should be made based on which makes the code more readable.
      *
      * @param endDate  the end date, exclusive, which may be in any chronology, not null
      * @return the period between this date and the end date, not null
      */
     @Override
-    public Period until(ChronoLocalDate endDate) {
-        LocalDate end = LocalDate.from(endDate);
+    public Period until(ChronoLocalDate endDateExclusive) {
+        LocalDate end = LocalDate.from(endDateExclusive);
         long totalMonths = end.getProlepticMonth() - this.getProlepticMonth();  // safe
         int days = end.day - this.day;
         if (totalMonths > 0 && days < 0) {
@@ -1642,12 +1642,12 @@
      * The choice should be made based on which makes the code more readable.
      *
-     * @param endDate  the end date, exclusive, which may be in any chronology, not null
+     * @param endDateExclusive  the end date, exclusive, which may be in any chronology, not null
      * @return the period between this date and the end date, not null
      */